YANG construct collision detection framework added

Change-Id: I1458f9e3192641f3f90c444798c31a64536ffa5d
diff --git a/src/main/java/org/onosproject/yangutils/parser/Parsable.java b/src/main/java/org/onosproject/yangutils/parser/Parsable.java
index 2beae10..0d220e5 100644
--- a/src/main/java/org/onosproject/yangutils/parser/Parsable.java
+++ b/src/main/java/org/onosproject/yangutils/parser/Parsable.java
@@ -17,6 +17,7 @@
 package org.onosproject.yangutils.parser;
 
 import org.onosproject.yangutils.datamodel.exceptions.DataModelException;
+import org.onosproject.yangutils.utils.YangConstructType;
 
 /**
  * Abstraction of an entity which process the data of lexer's parse tree.
@@ -24,11 +25,11 @@
 public interface Parsable {
 
     /**
      * Get the type of parsable data.
      *
      * @return the type of parsable data
      */
-    ParsableDataType getParsableDataType();
+    YangConstructType getYangConstructType();
 
     /**
      * Check if the node is valid as per YANG grammar's syntax and semantics.
@@ -24,11 +25,11 @@
 
     /**
-     * Get the type of parsable data.
+     * Get the type of YANG construct data.
      *
@@ -24,11 +25,11 @@
      *
-     * @return the type of parsable data
+     * @return the type of YANG construct data.
      */